complete -c dysk -l color -d 'whether to have styles and colors' -r -f -a "auto\t''
yes\t''
no\t''"
complete -c dysk -l remote-stats -d 'fetch stats of remote volumes' -r -f -a "auto\t''
yes\t''
no\t''"
complete -c dysk -s c -l cols -d 'columns, eg `-c +inodes` or `-c id+dev+default`' -r
complete -c dysk -s f -l filter -d 'filter, eg `-f \'(size<35G | remote=false) & type=xfs\'`' -r
complete -c dysk -s s -l sort -d 'sort, eg `inodes`, `type-desc`, or `size-asc`' -r
complete -c dysk -s u -l units -d 'units: `SI` (SI norm), `binary` (1024 based), or `bytes` (raw number)' -r
complete -c dysk -l csv-separator -d 'CSV separator' -r
complete -c dysk -l strategy -d 'strategy to use to find information, when several are available' -r
complete -c dysk -l timeout -d 'timeout to use for some operations, eg `10s` or `5ms`' -r
complete -c dysk -l help -d 'print help information'
complete -c dysk -l version -d 'print the version'
complete -c dysk -s a -l all -d 'show all mount points'
complete -c dysk -l ascii -d 'use only ASCII characters for table rendering'
complete -c dysk -l list-cols -d 'list the column names which can be used in -s, -f, or -c'
complete -c dysk -s j -l json -d 'output as JSON'
complete -c dysk -l csv -d 'output as CSV'
